package com.app.publishstream;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;

import com.flashphoner.fpwcsapi.Flashphoner;
import com.flashphoner.fpwcsapi.bean.Connection;
import com.flashphoner.fpwcsapi.bean.Data;
import com.flashphoner.fpwcsapi.bean.StreamStatus;
import com.flashphoner.fpwcsapi.session.Session;
import com.flashphoner.fpwcsapi.session.SessionEvent;
import com.flashphoner.fpwcsapi.session.SessionOptions;
import com.flashphoner.fpwcsapi.session.Stream;
import com.flashphoner.fpwcsapi.session.StreamOptions;
import com.flashphoner.fpwcsapi.session.StreamStatusEvent;

import org.webrtc.SurfaceViewRenderer;

/**
 * Created by webclues on 6/15/2018.
 */

public class PreviewActivity extends AppCompatActivity {

    public final String WCS_URL = "wss://wcs5-eu.flashphoner.com:8443";
    public final String STREAM_NAME = "TestChat";

    private Session session;

    private Stream playStream;

    private SurfaceViewRenderer remoteRender;

    private SessionOptions sessionOptions;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_preview);
        initControls();
    }

    private void initControls() {

        remoteRender = (SurfaceViewRenderer) findViewById(R.id.remote_video_view);
        remoteRender.setMirror(true);
        remoteRender.requestLayout();

        Flashphoner.init(this);

        liveStreamConnection();
    }

    private void liveStreamConnection() {

        sessionOptions = new SessionOptions(WCS_URL);
        sessionOptions.setRemoteRenderer(remoteRender);

        session = Flashphoner.createSession(sessionOptions);

        session.connect(new Connection());

        session.on(new SessionEvent() {
            @Override
            public void onAppData(Data data) {

            }

            @Override
            public void onConnected(final Connection connection) {
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        playStreamVideo();
                    }
                });
            }

            @Override
            public void onRegistered(Connection connection) {

            }

            @Override
            public void onDisconnection(final Connection connection) {
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {

                    }
                });
            }
        });

    }

    private void playStreamVideo() {

        StreamOptions streamOptions = new StreamOptions(STREAM_NAME);
        playStream = session.createStream(streamOptions);
        playStream.play();

        playStream.on(new StreamStatusEvent() {
            @Override
            public void onStreamStatus(final Stream stream, final StreamStatus streamStatus) {
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {

                        if (StreamStatus.PLAYING.equals(streamStatus)) {
                        } else if (StreamStatus.NOT_ENOUGH_BANDWIDTH.equals(streamStatus)) {
                            Log.e("TAG", "Not enough bandwidth stream " + stream.getName() + ", consider using lower video resolution or bitrate. " +
                                    "Bandwidth " + (Math.round(stream.getNetworkBandwidth() / 1000)) + " " +
                                    "bitrate " + (Math.round(stream.getRemoteBitrate() / 1000)));
                        } else {

                        }
                    }
                });
            }
        });

    }

    @Override
    protected void onResume() {
        super.onResume();
        try {
            remoteRender.init(Flashphoner.context, null);
        } catch (IllegalStateException e) {
            //ignore
        }
    }

    @Override
    protected void onPause() {
        super.onPause();
        remoteRender.release();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (session != null) {
            session.disconnect();
        }
    }
}
