package com.app.publishstream;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.ImageView;

import com.flashphoner.fpwcsapi.Flashphoner;
import com.flashphoner.fpwcsapi.bean.Connection;
import com.flashphoner.fpwcsapi.bean.Data;
import com.flashphoner.fpwcsapi.bean.StreamStatus;
import com.flashphoner.fpwcsapi.handler.CameraSwitchHandler;
import com.flashphoner.fpwcsapi.session.Session;
import com.flashphoner.fpwcsapi.session.SessionEvent;
import com.flashphoner.fpwcsapi.session.SessionOptions;
import com.flashphoner.fpwcsapi.session.Stream;
import com.flashphoner.fpwcsapi.session.StreamOptions;
import com.flashphoner.fpwcsapi.session.StreamStatusEvent;

import org.webrtc.SurfaceViewRenderer;

/**
 * Created by webclues on 6/15/2018.
 */

public class PublishActivity extends AppCompatActivity implements View.OnClickListener {

    private static final int PUBLISH_REQUEST_CODE = 100;

    public final String WCS_URL = "wss://wcs5-eu.flashphoner.com:8443";
    public final String STREAM_NAME = "TestChat";

    private Session session;

    private Stream publishStream;
    private Stream playStream;

    private SurfaceViewRenderer localRender;

    private SessionOptions sessionOptions;

    ImageView imgCamera;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_publish);
        initControls();
    }

    private void initControls() {

        imgCamera = findViewById(R.id.imgCamera);
        imgCamera.setOnClickListener(this);

        localRender = (SurfaceViewRenderer) findViewById(R.id.local_video_view);
        localRender.setZOrderMediaOverlay(true);
        localRender.setMirror(false);
        localRender.requestLayout();

        Flashphoner.init(this);

        liveStreamConnection();
    }

    private void liveStreamConnection() {

        sessionOptions = new SessionOptions(WCS_URL);
        sessionOptions.setLocalRenderer(localRender);

        session = Flashphoner.createSession(sessionOptions);

        session.connect(new Connection());

        session.on(new SessionEvent() {
            @Override
            public void onAppData(Data data) {

            }

            @Override
            public void onConnected(final Connection connection) {
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        publishStream();
                    }
                });
            }

            @Override
            public void onRegistered(Connection connection) {

            }

            @Override
            public void onDisconnection(final Connection connection) {
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {

                    }
                });
            }
        });
    }

    private void publishStream() {

        StreamOptions streamOptions = new StreamOptions(STREAM_NAME);
        publishStream = session.createStream(streamOptions);
        publishStream.on(new StreamStatusEvent() {
            @Override
            public void onStreamStatus(final Stream stream, final StreamStatus streamStatus) {
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        if (StreamStatus.PUBLISHING.equals(streamStatus)) {

                        } else {

                        }
                    }
                });
            }
        });
        publishStream.publish();
    }

    @Override
    protected void onResume() {
        super.onResume();
        try {
            localRender.init(Flashphoner.context, null);
        } catch (IllegalStateException e) {
            //ignore
        }
    }

    @Override
    protected void onPause() {
        super.onPause();
        localRender.release();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (session != null) {
            session.disconnect();
        }
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.imgCamera:
                if (publishStream != null) {
                    imgCamera.setEnabled(false);
                    publishStream.switchCamera(new CameraSwitchHandler() {
                        @Override
                        public void onCameraSwitchDone(boolean var1) {
                            runOnUiThread(new Runnable() {
                                @Override
                                public void run() {
                                    imgCamera.setEnabled(true);
                                }
                            });

                        }

                        @Override
                        public void onCameraSwitchError(String var1) {
                            runOnUiThread(new Runnable() {
                                @Override
                                public void run() {
                                    imgCamera.setEnabled(true);
                                }
                            });
                        }
                    });
                }
                break;
        }
    }
}
